|logo|

|build_status| |documentation_status|
|codecov|
|requirements|


Markdownreveal
==============

This tool allows you to create and visualize presentations with simple
Markdown notation. It is based on reveal.js and is able to generate the
required HTML and refresh your browser view for easier and faster
presentation creation.

- `Online presentation example <https://markdownreveal.github.io/example/>`_ 
  (`source code <https://github.com/markdownreveal/example>`_).
- `Documentation <https://markdownreveal.readthedocs.io/>`_.
- `Markdownreveal on Pypi <https://pypi.python.org/pypi/markdownreveal>`_.


.. |logo|
   image:: docs/source/logo/logo.png
      :width: 100px
      :target: https://markdownreveal.readthedocs.io/
.. |build_status|
   image:: https://api.travis-ci.org/markdownreveal/markdownreveal.svg?branch=master
      :target: https://travis-ci.org/markdownreveal/markdownreveal
.. |documentation_status|
   image:: https://readthedocs.org/projects/markdownreveal/badge/?version=stable
      :target: https://markdownreveal.readthedocs.io/
      :alt: Documentation badge
.. |codecov| image:: https://codecov.io/github/markdownreveal/markdownreveal/coverage.svg?branch=master
   :target: https://codecov.io/github/markdownreveal/markdownreveal
   :alt: Coverage (codecov) badge
.. |requirements| image:: https://requires.io/github/markdownreveal/markdownreveal/requirements.svg
   :target: https://requires.io/github/markdownreveal/markdownreveal/requirements/
   :alt: Requirements badge
